==> hazelcast-all-3.12.6-sources.jar: com/hazelcast/spi/impl/operationservice/impl/operations/PartitionAwareFactoryAccessor.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.spi.impl.operationservice.impl.operations;

import com.hazelcast.client.impl.operations.OperationFactoryWrapper;
import com.hazelcast.spi.OperationFactory;

public final class PartitionAwareFactoryAccessor {

    private PartitionAwareFactoryAccessor() {
    }

    /**
     * @param operationFactory operationFactory
     * @return extracted {@code PartitionAwareOperationFactory} from supplied operation factory or null
     */
    public static PartitionAwareOperationFactory extractPartitionAware(OperationFactory operationFactory) {
        if (operationFactory instanceof PartitionAwareOperationFactory) {
            return ((PartitionAwareOperationFactory) operationFactory);
        }

        if (operationFactory instanceof OperationFactoryWrapper) {
            OperationFactory unwrapped = ((OperationFactoryWrapper) operationFactory).getOperationFactory();
            if (unwrapped instanceof PartitionAwareOperationFactory) {
                return ((PartitionAwareOperationFactory) unwrapped);
            }
        }

        return null;
    }

}

==> hazelcast-all-4.1.7-sources.jar: com/hazelcast/spi/impl/operationservice/impl/operations/PartitionAwareFactoryAccessor.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.spi.impl.operationservice.impl.operations;

import com.hazelcast.client.impl.operations.OperationFactoryWrapper;
import com.hazelcast.spi.impl.operationservice.OperationFactory;

public final class PartitionAwareFactoryAccessor {

    private PartitionAwareFactoryAccessor() {
    }

    /**
     * @param operationFactory operationFactory
     * @return extracted {@code PartitionAwareOperationFactory} from supplied operation factory or null
     */
    public static PartitionAwareOperationFactory extractPartitionAware(OperationFactory operationFactory) {
        if (operationFactory instanceof PartitionAwareOperationFactory) {
            return ((PartitionAwareOperationFactory) operationFactory);
        }

        if (operationFactory instanceof OperationFactoryWrapper) {
            OperationFactory unwrapped = ((OperationFactoryWrapper) operationFactory).getOperationFactory();
            if (unwrapped instanceof PartitionAwareOperationFactory) {
                return ((PartitionAwareOperationFactory) unwrapped);
            }
        }

        return null;
    }

}
